package com.zhyc.module.base.mapper;

import java.util.List;
import com.zhyc.module.base.domain.BasSheepType;

/**
 * 羊只类型Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-22
 */
public interface BasSheepTypeMapper 
{
    /**
     * 查询羊只类型
     * 
     * @param id 羊只类型主键
     * @return 羊只类型
     */
    public BasSheepType selectBasSheepTypeById(Integer id);

    /**
     * 查询羊只类型列表
     * 
     * @param basSheepType 羊只类型
     * @return 羊只类型集合
     */
    public List<BasSheepType> selectBasSheepTypeList(BasSheepType basSheepType);

    /**
     * 新增羊只类型
     * 
     * @param basSheepType 羊只类型
     * @return 结果
     */
    public int insertBasSheepType(BasSheepType basSheepType);

    /**
     * 修改羊只类型
     * 
     * @param basSheepType 羊只类型
     * @return 结果
     */
    public int updateBasSheepType(BasSheepType basSheepType);

    /**
     * 删除羊只类型
     * 
     * @param id 羊只类型主键
     * @return 结果
     */
    public int deleteBasSheepTypeById(Integer id);

    /**
     * 批量删除羊只类型
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBasSheepTypeByIds(Integer[] ids);
}
